@@ -17,10 +17,8 @@ else:
 
 def run_command(input_command, env=None, cwd=None, mute=True):
     """Run a shell command.
-
     This function prints both STDOUT and STDERR to the same PIPE. Use shell piping
     to pipe the stdout from the commands to a file.
-
     Args:
         input_command: Input command.
         env: Additional environmental variable that will be added to global environment.
@@ -52,10 +50,22 @@ def run_command(input_command, env=None, cwd=None, mute=True):
     if not mute:
         print('running %s' % command)
 
-    process = subprocess.Popen(
-        command, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-        stderr=subprocess.STDOUT, shell=True, env=g_env
-    )
+    try:
+        process = subprocess.Popen(
+            command, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT, shell=True, env=g_env
+        )
+    except Exception as e:
+        # this is an edge case that is happening for certain commands on Mac when
+        # the command is executed from inside IronPython 2.7
+        # see: https://discourse.ladybug.tools/t/hdr-adjust-false-color-not-working-on-mac/16941/3
+        if 'Cannot redirect stderr to stdout yet' in str(e):
+            process = subprocess.Popen(
+                command, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE, shell=True, env=g_env
+            )
+        else:
+            raise ValueError(e)
 
     try:
         for line in iter(process.stdout.readline, STDOUT_CHECK):
@@ -68,12 +78,23 @@ def run_command(input_command, env=None, cwd=None, mute=True):
     except Exception:  # nothing in stdout
         pass
 
-    process.communicate()
+    _, stderr = process.communicate()
     rc = process.returncode
 
     if cwd:
         os.chdir(cur_dir)
 
+    try:
+        for line in iter(stderr.readline, STDOUT_CHECK):
+            try:
+                # Python 3 - almost all the time that we use this library
+                print(line.decode('utf-8'), end='')
+            except AttributeError:
+                # python 2 - line is already a string
+                print(line, end='')
+    except Exception:  # nothing in stderr
+        pass
+
     if rc != 0:
         raise RuntimeError('None zero return code: %d' % rc)
 
